==> hub_rest_client-0.1.1-py3-none-any.whl: hub_rest_client/api/default/get_services_service_id_untrustedredirecturis_untrusted_redirect_uri_id.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.untrusted_redirect_uri import UntrustedRedirectURI
from ...types import UNSET, Response, Unset


def _get_kwargs(
    service_id: str,
    untrusted_redirect_uri_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "redirectURI,triedFrom,triedAt",
) -> Dict[str, Any]:
    url = "{}/services/{serviceId}/untrustedredirecturis/{untrustedRedirectURIId}".format(
        client.hub_base_url, serviceId=service_id, untrustedRedirectURIId=untrusted_redirect_uri_id
    )

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[UntrustedRedirectURI]:
    if response.status_code == 200:
        response_200 = UntrustedRedirectURI.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[UntrustedRedirectURI]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    service_id: str,
    untrusted_redirect_uri_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "redirectURI,triedFrom,triedAt",
) -> Response[UntrustedRedirectURI]:
    kwargs = _get_kwargs(
        service_id=service_id,
        untrusted_redirect_uri_id=untrusted_redirect_uri_id,
        client=client,
        fields=fields,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    service_id: str,
    untrusted_redirect_uri_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "redirectURI,triedFrom,triedAt",
) -> Optional[UntrustedRedirectURI]:
    """ """

    return sync_detailed(
        service_id=service_id,
        untrusted_redirect_uri_id=untrusted_redirect_uri_id,
        client=client,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    service_id: str,
    untrusted_redirect_uri_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "redirectURI,triedFrom,triedAt",
) -> Response[UntrustedRedirectURI]:
    kwargs = _get_kwargs(
        service_id=service_id,
        untrusted_redirect_uri_id=untrusted_redirect_uri_id,
        client=client,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    service_id: str,
    untrusted_redirect_uri_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "redirectURI,triedFrom,triedAt",
) -> Optional[UntrustedRedirectURI]:
    """ """

    return (
        await asyncio_detailed(
            service_id=service_id,
            untrusted_redirect_uri_id=untrusted_redirect_uri_id,
            client=client,
            fields=fields,
        )
    ).parsed

==> hub_rest_client-0.1.2-py3-none-any.whl: hub_rest_client/api/default/get_services_service_id_untrustedredirecturis_untrusted_redirect_uri_id.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models import untrusted_redirect_uri as untrusted_redirect_uri_m
from ...types import UNSET, Response, Unset


def _get_kwargs(
    service_id: "str",
    untrusted_redirect_uri_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "redirectURI,triedFrom,triedAt",
) -> Dict[str, Any]:
    url = "{}/services/{serviceId}/untrustedredirecturis/{untrustedRedirectURIId}".format(
        client.hub_base_url, serviceId=service_id, untrustedRedirectURIId=untrusted_redirect_uri_id
    )

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[untrusted_redirect_uri_m.UntrustedRedirectURI]:
    if response.status_code == 200:
        response_200 = untrusted_redirect_uri_m.UntrustedRedirectURI.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[untrusted_redirect_uri_m.UntrustedRedirectURI]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    service_id: "str",
    untrusted_redirect_uri_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "redirectURI,triedFrom,triedAt",
) -> Response[untrusted_redirect_uri_m.UntrustedRedirectURI]:
    kwargs = _get_kwargs(
        service_id=service_id,
        untrusted_redirect_uri_id=untrusted_redirect_uri_id,
        client=client,
        fields=fields,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    service_id: "str",
    untrusted_redirect_uri_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "redirectURI,triedFrom,triedAt",
) -> Optional[untrusted_redirect_uri_m.UntrustedRedirectURI]:
    """ """

    return sync_detailed(
        service_id=service_id,
        untrusted_redirect_uri_id=untrusted_redirect_uri_id,
        client=client,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    service_id: "str",
    untrusted_redirect_uri_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "redirectURI,triedFrom,triedAt",
) -> Response[untrusted_redirect_uri_m.UntrustedRedirectURI]:
    kwargs = _get_kwargs(
        service_id=service_id,
        untrusted_redirect_uri_id=untrusted_redirect_uri_id,
        client=client,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    service_id: "str",
    untrusted_redirect_uri_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "redirectURI,triedFrom,triedAt",
) -> Optional[untrusted_redirect_uri_m.UntrustedRedirectURI]:
    """ """

    return (
        await asyncio_detailed(
            service_id=service_id,
            untrusted_redirect_uri_id=untrusted_redirect_uri_id,
            client=client,
            fields=fields,
        )
    ).parsed
